==> devops-client-java-1.0.0-sources.jar: io/alauda/devops/java/client/models/V1alpha1PipelineConfigSpecFluent.java <==
package io.alauda.devops.java.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.alauda.devops.java.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.alauda.devops.java.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.alauda.devops.java.client.fluent.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;

public interface V1alpha1PipelineConfigSpecFluent<A extends V1alpha1PipelineConfigSpecFluent<A>> extends Fluent<A>{


    public A addToHooks(int index,V1alpha1PipelineHook item);
    public A setToHooks(int index,V1alpha1PipelineHook item);
    public A addToHooks(V1alpha1PipelineHook... items);
    public A addAllToHooks(Collection<V1alpha1PipelineHook> items);
    public A removeFromHooks(V1alpha1PipelineHook... items);
    public A removeAllFromHooks(Collection<V1alpha1PipelineHook> items);
    
/**
 * This method has been deprecated, please use method buildHooks instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1PipelineHook> getHooks();
    public List<V1alpha1PipelineHook> buildHooks();
    public V1alpha1PipelineHook buildHook(int index);
    public V1alpha1PipelineHook buildFirstHook();
    public V1alpha1PipelineHook buildLastHook();
    public V1alpha1PipelineHook buildMatchingHook(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineHookBuilder> predicate);
    public Boolean hasMatchingHook(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineHookBuilder> predicate);
    public A withHooks(List<V1alpha1PipelineHook> hooks);
    public A withHooks(V1alpha1PipelineHook... hooks);
    public Boolean hasHooks();
    public V1alpha1PipelineConfigSpecFluent.HooksNested<A> addNewHook();
    public V1alpha1PipelineConfigSpecFluent.HooksNested<A> addNewHookLike(V1alpha1PipelineHook item);
    public V1alpha1PipelineConfigSpecFluent.HooksNested<A> setNewHookLike(int index,V1alpha1PipelineHook item);
    public V1alpha1PipelineConfigSpecFluent.HooksNested<A> editHook(int index);
    public V1alpha1PipelineConfigSpecFluent.HooksNested<A> editFirstHook();
    public V1alpha1PipelineConfigSpecFluent.HooksNested<A> editLastHook();
    public V1alpha1PipelineConfigSpecFluent.HooksNested<A> editMatchingHook(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineHookBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildJenkinsBinding instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1LocalObjectReference getJenkinsBinding();
    public V1alpha1LocalObjectReference buildJenkinsBinding();
    public A withJenkinsBinding(V1alpha1LocalObjectReference jenkinsBinding);
    public Boolean hasJenkinsBinding();
    public V1alpha1PipelineConfigSpecFluent.JenkinsBindingNested<A> withNewJenkinsBinding();
    public V1alpha1PipelineConfigSpecFluent.JenkinsBindingNested<A> withNewJenkinsBindingLike(V1alpha1LocalObjectReference item);
    public V1alpha1PipelineConfigSpecFluent.JenkinsBindingNested<A> editJenkinsBinding();
    public V1alpha1PipelineConfigSpecFluent.JenkinsBindingNested<A> editOrNewJenkinsBinding();
    public V1alpha1PipelineConfigSpecFluent.JenkinsBindingNested<A> editOrNewJenkinsBindingLike(V1alpha1LocalObjectReference item);
    public A addToParameters(int index,V1alpha1PipelineParameter item);
    public A setToParameters(int index,V1alpha1PipelineParameter item);
    public A addToParameters(V1alpha1PipelineParameter... items);
    public A addAllToParameters(Collection<V1alpha1PipelineParameter> items);
    public A removeFromParameters(V1alpha1PipelineParameter... items);
    public A removeAllFromParameters(Collection<V1alpha1PipelineParameter> items);
    
/**
 * This method has been deprecated, please use method buildParameters instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1PipelineParameter> getParameters();
    public List<V1alpha1PipelineParameter> buildParameters();
    public V1alpha1PipelineParameter buildParameter(int index);
    public V1alpha1PipelineParameter buildFirstParameter();
    public V1alpha1PipelineParameter buildLastParameter();
    public V1alpha1PipelineParameter buildMatchingParameter(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineParameterBuilder> predicate);
    public Boolean hasMatchingParameter(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineParameterBuilder> predicate);
    public A withParameters(List<V1alpha1PipelineParameter> parameters);
    public A withParameters(V1alpha1PipelineParameter... parameters);
    public Boolean hasParameters();
    public V1alpha1PipelineConfigSpecFluent.ParametersNested<A> addNewParameter();
    public V1alpha1PipelineConfigSpecFluent.ParametersNested<A> addNewParameterLike(V1alpha1PipelineParameter item);
    public V1alpha1PipelineConfigSpecFluent.ParametersNested<A> setNewParameterLike(int index,V1alpha1PipelineParameter item);
    public V1alpha1PipelineConfigSpecFluent.ParametersNested<A> editParameter(int index);
    public V1alpha1PipelineConfigSpecFluent.ParametersNested<A> editFirstParameter();
    public V1alpha1PipelineConfigSpecFluent.ParametersNested<A> editLastParameter();
    public V1alpha1PipelineConfigSpecFluent.ParametersNested<A> editMatchingParameter(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineParameterBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildRunLimits instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineRunLimits getRunLimits();
    public V1alpha1PipelineRunLimits buildRunLimits();
    public A withRunLimits(V1alpha1PipelineRunLimits runLimits);
    public Boolean hasRunLimits();
    public V1alpha1PipelineConfigSpecFluent.RunLimitsNested<A> withNewRunLimits();
    public V1alpha1PipelineConfigSpecFluent.RunLimitsNested<A> withNewRunLimitsLike(V1alpha1PipelineRunLimits item);
    public V1alpha1PipelineConfigSpecFluent.RunLimitsNested<A> editRunLimits();
    public V1alpha1PipelineConfigSpecFluent.RunLimitsNested<A> editOrNewRunLimits();
    public V1alpha1PipelineConfigSpecFluent.RunLimitsNested<A> editOrNewRunLimitsLike(V1alpha1PipelineRunLimits item);
    public String getRunPolicy();
    public A withRunPolicy(String runPolicy);
    public Boolean hasRunPolicy();
    public A withNewRunPolicy(String arg1);
    public A withNewRunPolicy(StringBuilder arg1);
    public A withNewRunPolicy(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildSource instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineSource getSource();
    public V1alpha1PipelineSource buildSource();
    public A withSource(V1alpha1PipelineSource source);
    public Boolean hasSource();
    public V1alpha1PipelineConfigSpecFluent.SourceNested<A> withNewSource();
    public V1alpha1PipelineConfigSpecFluent.SourceNested<A> withNewSourceLike(V1alpha1PipelineSource item);
    public V1alpha1PipelineConfigSpecFluent.SourceNested<A> editSource();
    public V1alpha1PipelineConfigSpecFluent.SourceNested<A> editOrNewSource();
    public V1alpha1PipelineConfigSpecFluent.SourceNested<A> editOrNewSourceLike(V1alpha1PipelineSource item);
    
/**
 * This method has been deprecated, please use method buildStrategy instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineStrategy getStrategy();
    public V1alpha1PipelineStrategy buildStrategy();
    public A withStrategy(V1alpha1PipelineStrategy strategy);
    public Boolean hasStrategy();
    public V1alpha1PipelineConfigSpecFluent.StrategyNested<A> withNewStrategy();
    public V1alpha1PipelineConfigSpecFluent.StrategyNested<A> withNewStrategyLike(V1alpha1PipelineStrategy item);
    public V1alpha1PipelineConfigSpecFluent.StrategyNested<A> editStrategy();
    public V1alpha1PipelineConfigSpecFluent.StrategyNested<A> editOrNewStrategy();
    public V1alpha1PipelineConfigSpecFluent.StrategyNested<A> editOrNewStrategyLike(V1alpha1PipelineStrategy item);
    
/**
 * This method has been deprecated, please use method buildTemplate instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineTemplateWithValue getTemplate();
    public V1alpha1PipelineTemplateWithValue buildTemplate();
    public A withTemplate(V1alpha1PipelineTemplateWithValue template);
    public Boolean hasTemplate();
    public V1alpha1PipelineConfigSpecFluent.TemplateNested<A> withNewTemplate();
    public V1alpha1PipelineConfigSpecFluent.TemplateNested<A> withNewTemplateLike(V1alpha1PipelineTemplateWithValue item);
    public V1alpha1PipelineConfigSpecFluent.TemplateNested<A> editTemplate();
    public V1alpha1PipelineConfigSpecFluent.TemplateNested<A> editOrNewTemplate();
    public V1alpha1PipelineConfigSpecFluent.TemplateNested<A> editOrNewTemplateLike(V1alpha1PipelineTemplateWithValue item);
    public A addToTriggers(int index,V1alpha1PipelineTrigger item);
    public A setToTriggers(int index,V1alpha1PipelineTrigger item);
    public A addToTriggers(V1alpha1PipelineTrigger... items);
    public A addAllToTriggers(Collection<V1alpha1PipelineTrigger> items);
    public A removeFromTriggers(V1alpha1PipelineTrigger... items);
    public A removeAllFromTriggers(Collection<V1alpha1PipelineTrigger> items);
    
/**
 * This method has been deprecated, please use method buildTriggers instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1PipelineTrigger> getTriggers();
    public List<V1alpha1PipelineTrigger> buildTriggers();
    public V1alpha1PipelineTrigger buildTrigger(int index);
    public V1alpha1PipelineTrigger buildFirstTrigger();
    public V1alpha1PipelineTrigger buildLastTrigger();
    public V1alpha1PipelineTrigger buildMatchingTrigger(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineTriggerBuilder> predicate);
    public Boolean hasMatchingTrigger(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineTriggerBuilder> predicate);
    public A withTriggers(List<V1alpha1PipelineTrigger> triggers);
    public A withTriggers(V1alpha1PipelineTrigger... triggers);
    public Boolean hasTriggers();
    public V1alpha1PipelineConfigSpecFluent.TriggersNested<A> addNewTrigger();
    public V1alpha1PipelineConfigSpecFluent.TriggersNested<A> addNewTriggerLike(V1alpha1PipelineTrigger item);
    public V1alpha1PipelineConfigSpecFluent.TriggersNested<A> setNewTriggerLike(int index,V1alpha1PipelineTrigger item);
    public V1alpha1PipelineConfigSpecFluent.TriggersNested<A> editTrigger(int index);
    public V1alpha1PipelineConfigSpecFluent.TriggersNested<A> editFirstTrigger();
    public V1alpha1PipelineConfigSpecFluent.TriggersNested<A> editLastTrigger();
    public V1alpha1PipelineConfigSpecFluent.TriggersNested<A> editMatchingTrigger(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineTriggerBuilder> predicate);

    public interface HooksNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineHookFluent<V1alpha1PipelineConfigSpecFluent.HooksNested<N>>{

        
    public N and();    public N endHook();
}
    public interface JenkinsBindingNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1LocalObjectReferenceFluent<V1alpha1PipelineConfigSpecFluent.JenkinsBindingNested<N>>{

        
    public N and();    public N endJenkinsBinding();
}
    public interface ParametersNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineParameterFluent<V1alpha1PipelineConfigSpecFluent.ParametersNested<N>>{

        
    public N and();    public N endParameter();
}
    public interface RunLimitsNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineRunLimitsFluent<V1alpha1PipelineConfigSpecFluent.RunLimitsNested<N>>{

        
    public N and();    public N endRunLimits();
}
    public interface SourceNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineSourceFluent<V1alpha1PipelineConfigSpecFluent.SourceNested<N>>{

        
    public N and();    public N endSource();
}
    public interface StrategyNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineStrategyFluent<V1alpha1PipelineConfigSpecFluent.StrategyNested<N>>{

        
    public N and();    public N endStrategy();
}
    public interface TemplateNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineTemplateWithValueFluent<V1alpha1PipelineConfigSpecFluent.TemplateNested<N>>{

        
    public N and();    public N endTemplate();
}
    public interface TriggersNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineTriggerFluent<V1alpha1PipelineConfigSpecFluent.TriggersNested<N>>{

        
    public N and();    public N endTrigger();
}


}

==> devops-client-java-1.0.6-sources.jar: io/alauda/devops/java/client/models/V1alpha1PipelineConfigSpecFluent.java <==
package io.alauda.devops.java.client.models;

import com.google.gson.annotations.SerializedName;
import java.util.ArrayList;
import java.lang.String;
import io.alauda.devops.java.client.fluent.Predicate;
import java.util.List;
import java.lang.Boolean;
import io.alauda.devops.java.client.fluent.Fluent;
import java.util.Collection;
import java.lang.StringBuilder;
import io.alauda.devops.java.client.fluent.Nested;
import java.lang.Deprecated;
import java.lang.StringBuffer;

public interface V1alpha1PipelineConfigSpecFluent<A extends V1alpha1PipelineConfigSpecFluent<A>> extends Fluent<A>{


    public A addToEnvironments(int index,V1alpha1PipelineEnvironment item);
    public A setToEnvironments(int index,V1alpha1PipelineEnvironment item);
    public A addToEnvironments(V1alpha1PipelineEnvironment... items);
    public A addAllToEnvironments(Collection<V1alpha1PipelineEnvironment> items);
    public A removeFromEnvironments(V1alpha1PipelineEnvironment... items);
    public A removeAllFromEnvironments(Collection<V1alpha1PipelineEnvironment> items);
    
/**
 * This method has been deprecated, please use method buildEnvironments instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1PipelineEnvironment> getEnvironments();
    public List<V1alpha1PipelineEnvironment> buildEnvironments();
    public V1alpha1PipelineEnvironment buildEnvironment(int index);
    public V1alpha1PipelineEnvironment buildFirstEnvironment();
    public V1alpha1PipelineEnvironment buildLastEnvironment();
    public V1alpha1PipelineEnvironment buildMatchingEnvironment(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineEnvironmentBuilder> predicate);
    public Boolean hasMatchingEnvironment(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineEnvironmentBuilder> predicate);
    public A withEnvironments(List<V1alpha1PipelineEnvironment> environments);
    public A withEnvironments(V1alpha1PipelineEnvironment... environments);
    public Boolean hasEnvironments();
    public V1alpha1PipelineConfigSpecFluent.EnvironmentsNested<A> addNewEnvironment();
    public V1alpha1PipelineConfigSpecFluent.EnvironmentsNested<A> addNewEnvironmentLike(V1alpha1PipelineEnvironment item);
    public V1alpha1PipelineConfigSpecFluent.EnvironmentsNested<A> setNewEnvironmentLike(int index,V1alpha1PipelineEnvironment item);
    public V1alpha1PipelineConfigSpecFluent.EnvironmentsNested<A> editEnvironment(int index);
    public V1alpha1PipelineConfigSpecFluent.EnvironmentsNested<A> editFirstEnvironment();
    public V1alpha1PipelineConfigSpecFluent.EnvironmentsNested<A> editLastEnvironment();
    public V1alpha1PipelineConfigSpecFluent.EnvironmentsNested<A> editMatchingEnvironment(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineEnvironmentBuilder> predicate);
    public A addToHooks(int index,V1alpha1PipelineHook item);
    public A setToHooks(int index,V1alpha1PipelineHook item);
    public A addToHooks(V1alpha1PipelineHook... items);
    public A addAllToHooks(Collection<V1alpha1PipelineHook> items);
    public A removeFromHooks(V1alpha1PipelineHook... items);
    public A removeAllFromHooks(Collection<V1alpha1PipelineHook> items);
    
/**
 * This method has been deprecated, please use method buildHooks instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1PipelineHook> getHooks();
    public List<V1alpha1PipelineHook> buildHooks();
    public V1alpha1PipelineHook buildHook(int index);
    public V1alpha1PipelineHook buildFirstHook();
    public V1alpha1PipelineHook buildLastHook();
    public V1alpha1PipelineHook buildMatchingHook(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineHookBuilder> predicate);
    public Boolean hasMatchingHook(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineHookBuilder> predicate);
    public A withHooks(List<V1alpha1PipelineHook> hooks);
    public A withHooks(V1alpha1PipelineHook... hooks);
    public Boolean hasHooks();
    public V1alpha1PipelineConfigSpecFluent.HooksNested<A> addNewHook();
    public V1alpha1PipelineConfigSpecFluent.HooksNested<A> addNewHookLike(V1alpha1PipelineHook item);
    public V1alpha1PipelineConfigSpecFluent.HooksNested<A> setNewHookLike(int index,V1alpha1PipelineHook item);
    public V1alpha1PipelineConfigSpecFluent.HooksNested<A> editHook(int index);
    public V1alpha1PipelineConfigSpecFluent.HooksNested<A> editFirstHook();
    public V1alpha1PipelineConfigSpecFluent.HooksNested<A> editLastHook();
    public V1alpha1PipelineConfigSpecFluent.HooksNested<A> editMatchingHook(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineHookBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildJenkinsBinding instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1LocalObjectReference getJenkinsBinding();
    public V1alpha1LocalObjectReference buildJenkinsBinding();
    public A withJenkinsBinding(V1alpha1LocalObjectReference jenkinsBinding);
    public Boolean hasJenkinsBinding();
    public V1alpha1PipelineConfigSpecFluent.JenkinsBindingNested<A> withNewJenkinsBinding();
    public V1alpha1PipelineConfigSpecFluent.JenkinsBindingNested<A> withNewJenkinsBindingLike(V1alpha1LocalObjectReference item);
    public V1alpha1PipelineConfigSpecFluent.JenkinsBindingNested<A> editJenkinsBinding();
    public V1alpha1PipelineConfigSpecFluent.JenkinsBindingNested<A> editOrNewJenkinsBinding();
    public V1alpha1PipelineConfigSpecFluent.JenkinsBindingNested<A> editOrNewJenkinsBindingLike(V1alpha1LocalObjectReference item);
    public A addToParameters(int index,V1alpha1PipelineParameter item);
    public A setToParameters(int index,V1alpha1PipelineParameter item);
    public A addToParameters(V1alpha1PipelineParameter... items);
    public A addAllToParameters(Collection<V1alpha1PipelineParameter> items);
    public A removeFromParameters(V1alpha1PipelineParameter... items);
    public A removeAllFromParameters(Collection<V1alpha1PipelineParameter> items);
    
/**
 * This method has been deprecated, please use method buildParameters instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1PipelineParameter> getParameters();
    public List<V1alpha1PipelineParameter> buildParameters();
    public V1alpha1PipelineParameter buildParameter(int index);
    public V1alpha1PipelineParameter buildFirstParameter();
    public V1alpha1PipelineParameter buildLastParameter();
    public V1alpha1PipelineParameter buildMatchingParameter(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineParameterBuilder> predicate);
    public Boolean hasMatchingParameter(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineParameterBuilder> predicate);
    public A withParameters(List<V1alpha1PipelineParameter> parameters);
    public A withParameters(V1alpha1PipelineParameter... parameters);
    public Boolean hasParameters();
    public V1alpha1PipelineConfigSpecFluent.ParametersNested<A> addNewParameter();
    public V1alpha1PipelineConfigSpecFluent.ParametersNested<A> addNewParameterLike(V1alpha1PipelineParameter item);
    public V1alpha1PipelineConfigSpecFluent.ParametersNested<A> setNewParameterLike(int index,V1alpha1PipelineParameter item);
    public V1alpha1PipelineConfigSpecFluent.ParametersNested<A> editParameter(int index);
    public V1alpha1PipelineConfigSpecFluent.ParametersNested<A> editFirstParameter();
    public V1alpha1PipelineConfigSpecFluent.ParametersNested<A> editLastParameter();
    public V1alpha1PipelineConfigSpecFluent.ParametersNested<A> editMatchingParameter(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineParameterBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildRunLimits instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineRunLimits getRunLimits();
    public V1alpha1PipelineRunLimits buildRunLimits();
    public A withRunLimits(V1alpha1PipelineRunLimits runLimits);
    public Boolean hasRunLimits();
    public V1alpha1PipelineConfigSpecFluent.RunLimitsNested<A> withNewRunLimits();
    public V1alpha1PipelineConfigSpecFluent.RunLimitsNested<A> withNewRunLimitsLike(V1alpha1PipelineRunLimits item);
    public V1alpha1PipelineConfigSpecFluent.RunLimitsNested<A> editRunLimits();
    public V1alpha1PipelineConfigSpecFluent.RunLimitsNested<A> editOrNewRunLimits();
    public V1alpha1PipelineConfigSpecFluent.RunLimitsNested<A> editOrNewRunLimitsLike(V1alpha1PipelineRunLimits item);
    public String getRunPolicy();
    public A withRunPolicy(String runPolicy);
    public Boolean hasRunPolicy();
    public A withNewRunPolicy(String arg1);
    public A withNewRunPolicy(StringBuilder arg1);
    public A withNewRunPolicy(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildSource instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineSource getSource();
    public V1alpha1PipelineSource buildSource();
    public A withSource(V1alpha1PipelineSource source);
    public Boolean hasSource();
    public V1alpha1PipelineConfigSpecFluent.SourceNested<A> withNewSource();
    public V1alpha1PipelineConfigSpecFluent.SourceNested<A> withNewSourceLike(V1alpha1PipelineSource item);
    public V1alpha1PipelineConfigSpecFluent.SourceNested<A> editSource();
    public V1alpha1PipelineConfigSpecFluent.SourceNested<A> editOrNewSource();
    public V1alpha1PipelineConfigSpecFluent.SourceNested<A> editOrNewSourceLike(V1alpha1PipelineSource item);
    
/**
 * This method has been deprecated, please use method buildStrategy instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineStrategy getStrategy();
    public V1alpha1PipelineStrategy buildStrategy();
    public A withStrategy(V1alpha1PipelineStrategy strategy);
    public Boolean hasStrategy();
    public V1alpha1PipelineConfigSpecFluent.StrategyNested<A> withNewStrategy();
    public V1alpha1PipelineConfigSpecFluent.StrategyNested<A> withNewStrategyLike(V1alpha1PipelineStrategy item);
    public V1alpha1PipelineConfigSpecFluent.StrategyNested<A> editStrategy();
    public V1alpha1PipelineConfigSpecFluent.StrategyNested<A> editOrNewStrategy();
    public V1alpha1PipelineConfigSpecFluent.StrategyNested<A> editOrNewStrategyLike(V1alpha1PipelineStrategy item);
    
/**
 * This method has been deprecated, please use method buildTemplate instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineTemplateWithValue getTemplate();
    public V1alpha1PipelineTemplateWithValue buildTemplate();
    public A withTemplate(V1alpha1PipelineTemplateWithValue template);
    public Boolean hasTemplate();
    public V1alpha1PipelineConfigSpecFluent.TemplateNested<A> withNewTemplate();
    public V1alpha1PipelineConfigSpecFluent.TemplateNested<A> withNewTemplateLike(V1alpha1PipelineTemplateWithValue item);
    public V1alpha1PipelineConfigSpecFluent.TemplateNested<A> editTemplate();
    public V1alpha1PipelineConfigSpecFluent.TemplateNested<A> editOrNewTemplate();
    public V1alpha1PipelineConfigSpecFluent.TemplateNested<A> editOrNewTemplateLike(V1alpha1PipelineTemplateWithValue item);
    public A addToTriggers(int index,V1alpha1PipelineTrigger item);
    public A setToTriggers(int index,V1alpha1PipelineTrigger item);
    public A addToTriggers(V1alpha1PipelineTrigger... items);
    public A addAllToTriggers(Collection<V1alpha1PipelineTrigger> items);
    public A removeFromTriggers(V1alpha1PipelineTrigger... items);
    public A removeAllFromTriggers(Collection<V1alpha1PipelineTrigger> items);
    
/**
 * This method has been deprecated, please use method buildTriggers instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1PipelineTrigger> getTriggers();
    public List<V1alpha1PipelineTrigger> buildTriggers();
    public V1alpha1PipelineTrigger buildTrigger(int index);
    public V1alpha1PipelineTrigger buildFirstTrigger();
    public V1alpha1PipelineTrigger buildLastTrigger();
    public V1alpha1PipelineTrigger buildMatchingTrigger(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineTriggerBuilder> predicate);
    public Boolean hasMatchingTrigger(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineTriggerBuilder> predicate);
    public A withTriggers(List<V1alpha1PipelineTrigger> triggers);
    public A withTriggers(V1alpha1PipelineTrigger... triggers);
    public Boolean hasTriggers();
    public V1alpha1PipelineConfigSpecFluent.TriggersNested<A> addNewTrigger();
    public V1alpha1PipelineConfigSpecFluent.TriggersNested<A> addNewTriggerLike(V1alpha1PipelineTrigger item);
    public V1alpha1PipelineConfigSpecFluent.TriggersNested<A> setNewTriggerLike(int index,V1alpha1PipelineTrigger item);
    public V1alpha1PipelineConfigSpecFluent.TriggersNested<A> editTrigger(int index);
    public V1alpha1PipelineConfigSpecFluent.TriggersNested<A> editFirstTrigger();
    public V1alpha1PipelineConfigSpecFluent.TriggersNested<A> editLastTrigger();
    public V1alpha1PipelineConfigSpecFluent.TriggersNested<A> editMatchingTrigger(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineTriggerBuilder> predicate);

    public interface EnvironmentsNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineEnvironmentFluent<V1alpha1PipelineConfigSpecFluent.EnvironmentsNested<N>>{

        
    public N and();    public N endEnvironment();
}
    public interface HooksNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineHookFluent<V1alpha1PipelineConfigSpecFluent.HooksNested<N>>{

        
    public N and();    public N endHook();
}
    public interface JenkinsBindingNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1LocalObjectReferenceFluent<V1alpha1PipelineConfigSpecFluent.JenkinsBindingNested<N>>{

        
    public N and();    public N endJenkinsBinding();
}
    public interface ParametersNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineParameterFluent<V1alpha1PipelineConfigSpecFluent.ParametersNested<N>>{

        
    public N and();    public N endParameter();
}
    public interface RunLimitsNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineRunLimitsFluent<V1alpha1PipelineConfigSpecFluent.RunLimitsNested<N>>{

        
    public N and();    public N endRunLimits();
}
    public interface SourceNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineSourceFluent<V1alpha1PipelineConfigSpecFluent.SourceNested<N>>{

        
    public N and();    public N endSource();
}
    public interface StrategyNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineStrategyFluent<V1alpha1PipelineConfigSpecFluent.StrategyNested<N>>{

        
    public N and();    public N endStrategy();
}
    public interface TemplateNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineTemplateWithValueFluent<V1alpha1PipelineConfigSpecFluent.TemplateNested<N>>{

        
    public N and();    public N endTemplate();
}
    public interface TriggersNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineTriggerFluent<V1alpha1PipelineConfigSpecFluent.TriggersNested<N>>{

        
    public N and();    public N endTrigger();
}


}
